@@ -1,12 +1,12 @@
-## ---- echo=FALSE--------------------------------------------------------------
-knitr::opts_chunk$set(fig.width = 7, 
+## ----echo=FALSE---------------------------------------------------------------
+knitr::opts_chunk$set(fig.width = 7,
                       fig.height = 3)
 
 ## -----------------------------------------------------------------------------
 library(forestplot)
 library(dplyr)
 
-## ---- fig.height=4, fig.width=8, message=FALSE--------------------------------
+## ----fig.height=4, fig.width=8, message=FALSE---------------------------------
 # Cochrane data from the 'rmeta'-package
 base_data <- tibble::tibble(mean  = c(0.578, 0.165, 0.246, 0.700, 0.348, 0.139, 1.017),
                             lower = c(0.372, 0.018, 0.072, 0.333, 0.083, 0.016, 0.365),
@@ -23,7 +23,7 @@ base_data |>
              xlog = TRUE) |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
-               summary = "royalblue") |> 
+               summary = "royalblue") |>
   fp_add_header(study = c("", "Study"),
                 deaths_steroid = c("Deaths", "(steroid)"),
                 deaths_placebo = c("Deaths", "(placebo)"),
@@ -33,24 +33,24 @@ base_data |>
                 upper = 0.731,
                 study = "Summary",
                 OR = "0.53",
-                is.summary = TRUE) |> 
+                is.summary = TRUE) |>
   fp_set_zebra_style("#EFEFEF")
 
-## ---- fig.height=4, fig.width=8, message=FALSE--------------------------------
-base_data |> 
-  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR), 
-             clip = c(0.1, 2.5), 
-             xlog = TRUE) |> 
-  fp_add_lines() |> 
+## ----fig.height=4, fig.width=8, message=FALSE---------------------------------
+base_data |>
+  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR),
+             clip = c(0.1, 2.5),
+             xlog = TRUE) |>
+  fp_add_lines() |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
                align = "lrrr",
-               hrz_lines = "#999999") |> 
+               hrz_lines = "#999999") |>
   fp_add_header(study = c("", "Study"),
-                deaths_steroid = c("Deaths", "(steroid)") |> 
+                deaths_steroid = c("Deaths", "(steroid)") |>
                   fp_align_center(),
-                deaths_placebo = c("Deaths", "(placebo)") |> 
+                deaths_placebo = c("Deaths", "(placebo)") |>
                   fp_align_center(),
                 OR = c("", fp_align_center("OR"))) |>
   fp_append_row(mean  = 0.531,
@@ -60,22 +60,22 @@ base_data |>
                 OR = "0.53",
                 is.summary = TRUE)
 
-## ---- fig.height=4, fig.width=8, message=FALSE--------------------------------
-base_data |> 
-  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR), 
-             clip = c(0.1, 2.5), 
-             xlog = TRUE) |> 
-  fp_add_lines(h_3 = gpar(lty = 2), 
-               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |> 
+## ----fig.height=4, fig.width=8, message=FALSE---------------------------------
+base_data |>
+  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR),
+             clip = c(0.1, 2.5),
+             xlog = TRUE) |>
+  fp_add_lines(h_3 = gpar(lty = 2),
+               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
                align = "lrrr",
-               hrz_lines = "#999999") |> 
+               hrz_lines = "#999999") |>
   fp_add_header(study = c("", "Study"),
-                deaths_steroid = c("Deaths", "(steroid)") |> 
+                deaths_steroid = c("Deaths", "(steroid)") |>
                   fp_align_center(),
-                deaths_placebo = c("Deaths", "(placebo)") |> 
+                deaths_placebo = c("Deaths", "(placebo)") |>
                   fp_align_center(),
                 OR = c("", fp_align_center("OR"))) |>
   fp_append_row(mean  = 0.531,
@@ -85,23 +85,23 @@ base_data |>
                 OR = "0.53",
                 is.summary = TRUE)
 
-## ---- fig.height=4, fig.width=8, message=FALSE--------------------------------
-base_data |> 
-  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR), 
-             clip = c(0.1, 2.5), 
+## ----fig.height=4, fig.width=8, message=FALSE---------------------------------
+base_data |>
+  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR),
+             clip = c(0.1, 2.5),
              vertices = TRUE,
-             xlog = TRUE) |> 
-  fp_add_lines(h_3 = gpar(lty = 2), 
-               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |> 
+             xlog = TRUE) |>
+  fp_add_lines(h_3 = gpar(lty = 2),
+               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
                align = "lrrr",
-               hrz_lines = "#999999")  |> 
+               hrz_lines = "#999999")  |>
   fp_add_header(study = c("", "Study"),
-                deaths_steroid = c("Deaths", "(steroid)") |> 
+                deaths_steroid = c("Deaths", "(steroid)") |>
                   fp_align_center(),
-                deaths_placebo = c("Deaths", "(placebo)") |> 
+                deaths_placebo = c("Deaths", "(placebo)") |>
                   fp_align_center(),
                 OR = c("", fp_align_center("OR"))) |>
   fp_append_row(mean  = 0.531,
@@ -112,17 +112,17 @@ base_data |>
                 is.summary = TRUE)
 
 ## -----------------------------------------------------------------------------
-base_data |> 
-  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR), 
-             clip = c(0.1, 2.5), 
+base_data |>
+  forestplot(labeltext = c(study, deaths_steroid, deaths_placebo, OR),
+             clip = c(0.1, 2.5),
              vertices = TRUE,
-             xlog = TRUE) |> 
-  fp_add_lines(h_3 = gpar(lty = 2), 
-               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |> 
+             xlog = TRUE) |>
+  fp_add_lines(h_3 = gpar(lty = 2),
+               h_11 = gpar(lwd = 1, columns = 1:4, col = "#000044")) |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
-               hrz_lines = "#999999") |> 
+               hrz_lines = "#999999") |>
   fp_add_header(study = c("", "Study"),
                 deaths_steroid = c("Deaths", "(steroid)"),
                 deaths_placebo = c("Deaths", "(placebo)"),
@@ -132,20 +132,20 @@ base_data |>
                 upper = 0.731,
                 study = "Summary",
                 OR = "0.53",
-                is.summary = TRUE) |> 
+                is.summary = TRUE) |>
   fp_decorate_graph(box = gpar(lty = 2, col = "lightgray"),
-                    graph.pos = 4) |> 
+                    graph.pos = 4) |>
   fp_set_zebra_style("#f9f9f9")
 
 ## -----------------------------------------------------------------------------
 data(dfHRQoL)
 
-dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
-             xlab = "EQ-5D index") |> 
-  fp_add_header(est = expression(beta)) |> 
+dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
+             xlab = "EQ-5D index") |>
+  fp_add_header(est = expression(beta)) |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue")
@@ -156,24 +156,24 @@ font <- "mono"
 if (grepl("Ubuntu", Sys.info()["version"])) {
   font <- "HersheyGothicEnglish"
 }
-dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
-             xlab = "EQ-5D index") |> 
-  fp_add_header(est = "Est.") |> 
+dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
+             xlab = "EQ-5D index") |>
+  fp_add_header(est = "Est.") |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
                txt_gp = fpTxtGp(label = gpar(fontfamily = font)))
 
 ## -----------------------------------------------------------------------------
-dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
-             xlab = "EQ-5D index") |> 
-  fp_add_header(est = "Est.") |> 
+dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
+             xlab = "EQ-5D index") |>
+  fp_add_header(est = "Est.") |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue",
@@ -184,42 +184,42 @@ dfHRQoL |>
                                 xlab  = gpar(fontfamily = font, cex = 1.5)))
 
 ## -----------------------------------------------------------------------------
-dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
+dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
              clip = c(-.1, Inf),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue")
 
 ## -----------------------------------------------------------------------------
-dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
+dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
              boxsize = 0.2,
              clip = c(-.1, Inf),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue")
 
 ## ----fig.width=10, fig.height=4-----------------------------------------------
-fp_sweden <- dfHRQoL |> 
-  filter(group == "Sweden") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
+fp_sweden <- dfHRQoL |>
+  filter(group == "Sweden") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
              title = "Sweden",
              clip = c(-.1, Inf),
              xlab = "EQ-5D index",
              new_page = FALSE)
 
-fp_denmark <- dfHRQoL |> 
-  filter(group == "Denmark") |> 
-  mutate(est = sprintf("%.2f", mean), .after = labeltext) |> 
-  forestplot(labeltext = c(labeltext, est), 
+fp_denmark <- dfHRQoL |>
+  filter(group == "Denmark") |>
+  mutate(est = sprintf("%.2f", mean), .after = labeltext) |>
+  forestplot(labeltext = c(labeltext, est),
              title = "Denmark",
              clip = c(-.1, Inf),
              xlab = "EQ-5D index",
@@ -229,8 +229,8 @@ library(grid)
 grid.newpage()
 borderWidth <- unit(4, "pt")
 width <- unit(convertX(unit(1, "npc") - borderWidth, unitTo = "npc", valueOnly = TRUE)/2, "npc")
-pushViewport(viewport(layout = grid.layout(nrow = 1, 
-                                           ncol = 3, 
+pushViewport(viewport(layout = grid.layout(nrow = 1,
+                                           ncol = 3,
                                            widths = unit.c(width,
                                                            borderWidth,
                                                            width))
@@ -238,7 +238,7 @@ pushViewport(viewport(layout = grid.layout(nrow = 1,
              )
 pushViewport(viewport(layout.pos.row = 1,
                       layout.pos.col = 1))
-fp_sweden |> 
+fp_sweden |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue")
@@ -249,7 +249,7 @@ grid.rect(gp = gpar(fill = "#dddddd", col = "#eeeeee"))
 upViewport()
 pushViewport(viewport(layout.pos.row = 1,
                       layout.pos.col = 3))
-fp_denmark |> 
+fp_denmark |>
   fp_set_style(box = "royalblue",
                line = "darkblue",
                summary = "royalblue")
@@ -262,9 +262,10 @@ dfHRQoL |>
              ci.vertices = TRUE,
              ci.vertices.height = 0.05,
              boxsize = .1,
-             xlab = "EQ-5D index") |> 
-  fp_add_lines("steelblue") |> 
-  fp_add_header("Variable") |> 
+             lineheight = "lines",
+             xlab = "EQ-5D index") |>
+  fp_add_lines("steelblue") |>
+  fp_add_header("Variable") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")),
                default = gpar(vertices = TRUE))
 
@@ -275,9 +276,9 @@ dfHRQoL |>
              boxsize = .25, # We set the box size to better visualize the type
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")),
-               default = gpar(vertices = TRUE)) |> 
+               default = gpar(vertices = TRUE)) |>
   fp_set_zebra_style("#F5F9F9")
 
 ## -----------------------------------------------------------------------------
@@ -288,7 +289,7 @@ dfHRQoL |>
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
              lty.ci = c(1, 2),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")),
                default = gpar(vertices = TRUE))
 
@@ -300,20 +301,20 @@ dfHRQoL |>
              boxsize = .25, # We set the box size to better visualize the type
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")))
 
 ## -----------------------------------------------------------------------------
 dfHRQoL |>
   group_by(group) |>
   forestplot(legend = c("Swedes", "Danes"),
-             legend_args = fpLegend(pos = list(x = .85, y = 0.25), 
+             legend_args = fpLegend(pos = list(x = .85, y = 0.25),
                                     gp = gpar(col = "#CCCCCC", fill = "#F9F9F9")),
              fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
              boxsize = .25, # We set the box size to better visualize the type
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")))
 
 ## -----------------------------------------------------------------------------
@@ -324,7 +325,7 @@ dfHRQoL |>
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
              xticks = c(-.1, -0.05, 0, .05),
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")))
 
 ## -----------------------------------------------------------------------------
@@ -339,7 +340,7 @@ dfHRQoL |>
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
              xticks = xticks,
-             xlab = "EQ-5D index") |> 
+             xlab = "EQ-5D index") |>
   fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555")))
 
 ## -----------------------------------------------------------------------------
@@ -351,9 +352,9 @@ dfHRQoL |>
              clip = c(-.125, 0.075),
              xticks = c(-.1, -0.05, 0, .05),
              zero = 0,
-             xlab = "EQ-5D index") |> 
-  fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555"))) |> 
-  fp_decorate_graph(grid = structure(c(-.1, -.05, .05), 
+             xlab = "EQ-5D index") |>
+  fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555"))) |>
+  fp_decorate_graph(grid = structure(c(-.1, -.05, .05),
                               gp = gpar(lty = 2, col = "#CCCCFF")))
 
 ## -----------------------------------------------------------------------------
@@ -363,12 +364,12 @@ dfHRQoL |>
              boxsize = .25, # We set the box size to better visualize the type
              line.margin = .1, # We need to add this to avoid crowding
              clip = c(-.125, 0.075),
-             xlab = "EQ-5D index") |> 
-  fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555"))) |> 
-  fp_decorate_graph(grid = structure(c(-.1, -.05, .05), 
+             xlab = "EQ-5D index") |>
+  fp_set_style(box = c("blue", "darkred") |> lapply(function(x) gpar(fill = x, col = "#555555"))) |>
+  fp_decorate_graph(grid = structure(c(-.1, -.05, .05),
                                      gp = gpar(lty = 2, col = "#CCCCFF")))
 
-## ---- eval=FALSE, echo=TRUE---------------------------------------------------
+## ----eval=FALSE, echo=TRUE----------------------------------------------------
 #  grid_arg <- c(-.1, -.05, .05)
 #  attr(grid_arg, "gp") <- gpar(lty = 2, col = "#CCCCFF")
 #  
